@@ -18,12 +18,15 @@
  * */
 
 #include "screenshooter-actions.h"
+#include "screenshooter-custom-actions.h"
 #include "screenshooter-utils.h"
 #include "screenshooter-capture.h"
 #include "screenshooter-global.h"
 #include "screenshooter-dialogs.h"
 #include "screenshooter-imgur.h"
 
+
+
 static void
 cb_help_response (GtkWidget *dialog, gint response, gpointer unused)
 {
@@ -128,7 +131,7 @@ action_idle (gpointer user_data)
       GFile *temp_dir = g_file_new_for_path (g_get_tmp_dir ());
       gchar *temp_dir_uri = g_file_get_uri (temp_dir);
       gchar *filename = screenshooter_get_filename_for_uri (temp_dir_uri,
-                                                            sd->title, 
+                                                            sd->title,
                                                             sd->last_extension,
                                                             sd->timestamp);
       save_location = screenshooter_save_screenshot (sd->screenshot,
@@ -137,6 +140,7 @@ action_idle (gpointer user_data)
                                                      sd->last_extension,
                                                      FALSE,
                                                      FALSE);
+
       g_object_unref (temp_dir);
       g_free (temp_dir_uri);
       g_free (filename);
@@ -159,6 +163,10 @@ action_idle (gpointer user_data)
                   return TRUE;
                 }
             }
+          else if (sd->action & CUSTOM_ACTION)
+            {
+              screenshooter_custom_action_execute (save_location, sd->custom_action_name, sd->custom_action_command);
+            }
         }
     }
 
