@@ -335,7 +335,7 @@ static GdkPixbuf
 
   root = gdk_get_default_root_window ();
 
-  if ((has_extents = screenshooter_get_gtk_frame_extents (window, &extents)))
+  if ((has_extents = xfce_has_gtk_frame_extents (window, &extents)))
     border = FALSE;
 
   if (border) {
