@@ -25,6 +25,9 @@
 #include <libsoup/soup.h>
 #include <libxml/parser.h>
 
+/* for v3 API - key registered *only* for xfce4-screenshooter! */
+#define HEADER_CLIENT_ID "Client-ID 66ab680b597e293"
+
 static gboolean          imgur_upload_job          (ScreenshooterJob  *job,
                                                     GArray            *param_values,
                                                     GError           **error);
@@ -36,18 +39,25 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
   guchar *online_file_name = NULL;
   guchar *delete_hash = NULL;
   const gchar *proxy_uri;
-  GUri *soup_proxy_uri;
 #ifdef DEBUG
   SoupLogger *log;
 #endif
   SoupSession *session;
   SoupMessage *msg;
-  GBytes *buf, *response;
   GMappedFile *mapping;
   SoupMultipart *mp;
   xmlDoc *doc;
   xmlNode *root_node, *child_node;
 
+#ifdef HAVE_SOUP3
+  GUri *soup_proxy_uri;
+  GBytes *buf, *response;
+#else
+  SoupURI *soup_proxy_uri;
+  guint status;
+  SoupBuffer *buf;
+#endif
+
   const gchar *upload_url = "https://api.imgur.com/3/upload.xml";
 
   GError *tmp_error = NULL;
@@ -69,7 +79,11 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
 
   session = soup_session_new ();
 #ifdef DEBUG
+#ifdef HAVE_SOUP3
   log = soup_logger_new (SOUP_LOGGER_LOG_HEADERS);
+#else
+  log = soup_logger_new (SOUP_LOGGER_LOG_HEADERS, -1);
+#endif
   soup_session_add_feature (session, (SoupSessionFeature *)log);
 #endif
 
@@ -78,9 +92,15 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
 
   if (proxy_uri != NULL)
     {
+#ifdef HAVE_SOUP3
       soup_proxy_uri = g_uri_parse (proxy_uri, G_URI_FLAGS_NONE, NULL);
       g_object_set (session, "proxy-uri", soup_proxy_uri, NULL);
       g_uri_unref (soup_proxy_uri);
+#else
+      soup_proxy_uri = soup_uri_new (proxy_uri);
+      g_object_set (session, "proxy-uri", soup_proxy_uri, NULL);
+      soup_uri_free (soup_proxy_uri);
+#endif
     }
 
   mapping = g_mapped_file_new (image_path, FALSE, NULL);
@@ -89,18 +109,30 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
     return FALSE;
   }
 
-  mp = soup_multipart_new(SOUP_FORM_MIME_TYPE_MULTIPART);
+#ifdef HAVE_SOUP3
   buf = g_mapped_file_get_bytes (mapping);
+#else
+  buf = soup_buffer_new_with_owner (g_mapped_file_get_contents (mapping),
+                                    g_mapped_file_get_length (mapping),
+                                    mapping, (GDestroyNotify)g_mapped_file_unref);
+#endif
 
+  mp = soup_multipart_new (SOUP_FORM_MIME_TYPE_MULTIPART);
   soup_multipart_append_form_file (mp, "image", NULL, NULL, buf);
   soup_multipart_append_form_string (mp, "name", title);
   soup_multipart_append_form_string (mp, "title", title);
-  msg = soup_message_new_from_multipart (upload_url, mp);
 
-  /* for v3 API - key registered *only* for xfce4-screenshooter! */
-  soup_message_headers_append (soup_message_get_request_headers (msg), "Authorization", "Client-ID 66ab680b597e293");
+#ifdef HAVE_SOUP3
+  msg = soup_message_new_from_multipart (upload_url, mp);
+  soup_message_headers_append (soup_message_get_request_headers (msg), "Authorization", HEADER_CLIENT_ID);
+#else
+  msg = soup_form_request_new_from_multipart (upload_url, mp);
+  soup_message_headers_append (msg->request_headers, "Authorization", HEADER_CLIENT_ID);
+#endif
+
   exo_job_info_message (EXO_JOB (job), _("Upload the screenshot..."));
 
+#ifdef HAVE_SOUP3
   response = soup_session_send_and_read (session, msg, NULL, &tmp_error);
 
   g_mapped_file_unref (mapping);
@@ -121,6 +153,29 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
   TRACE("response was %s\n", (gchar*) g_bytes_get_data (response, NULL));
   /* returned XML is like <data type="array" success="1" status="200"><id>xxxxxx</id> */
   doc = xmlParseMemory (g_bytes_get_data (response, NULL), g_bytes_get_size (response));
+#else
+  status = soup_session_send_message (session, msg);
+
+  if (!SOUP_STATUS_IS_SUCCESSFUL (status))
+    {
+      TRACE ("Error during the POST exchange: %d %s\n",
+             status, msg->reason_phrase);
+
+      tmp_error = g_error_new (SOUP_HTTP_ERROR,
+                         status,
+                         _("An error occurred while transferring the data"
+                           " to imgur."));
+      g_propagate_error (error, tmp_error);
+      g_object_unref (session);
+      g_object_unref (msg);
+
+      return FALSE;
+    }
+
+  TRACE("response was %s\n", msg->response_body->data);
+  /* returned XML is like <data type="array" success="1" status="200"><id>xxxxxx</id> */
+  doc = xmlParseMemory(msg->response_body->data, strlen(msg->response_body->data));
+#endif
 
   root_node = xmlDocGetRootElement(doc);
   for (child_node = root_node->children; child_node; child_node = child_node->next)
@@ -133,14 +188,20 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
 
   TRACE("found picture id %s\n", online_file_name);
   xmlFreeDoc(doc);
-  g_bytes_unref (response);
 
   screenshooter_job_image_uploaded (job,
                                     (const gchar*) online_file_name,
                                     (const gchar*) delete_hash);
 
+#ifdef HAVE_SOUP3
+  g_bytes_unref (response);
   g_free (online_file_name);
   g_free (delete_hash);
+#else
+  soup_buffer_free (buf);
+  g_object_unref (session);
+  g_object_unref (msg);
+#endif
 
   return TRUE;
 }
