@@ -230,6 +230,7 @@ int main (int argc, char **argv)
   sd->path_is_dir = TRUE;
   sd->app_info = NULL;
   sd->action = 0;
+  sd->custom_action_name = g_strdup ("none");
 
   /* Read the preferences */
   rc_file = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, "xfce4/xfce4-screenshooter", TRUE);
@@ -239,16 +240,13 @@ int main (int argc, char **argv)
   sd->action_specified = FALSE;
 
   /* Check if the directory read from the preferences is valid */
-  default_save_dir = g_file_new_for_uri (sd->screenshot_dir);
-
-  if (G_UNLIKELY (!g_file_query_exists (default_save_dir, NULL)))
+  if (G_UNLIKELY (!screenshooter_is_directory_writable (sd->screenshot_dir)))
     {
+      g_warning ("Invalid directory or permissions: %s", sd->screenshot_dir);
       g_free (sd->screenshot_dir);
       sd->screenshot_dir = screenshooter_get_xdg_image_dir_uri ();
     }
 
-  g_object_unref (default_save_dir);
-
   /* If a region cli option is given, take the screenshot accordingly.*/
   if (fullscreen || window || region)
     {
@@ -310,7 +308,7 @@ int main (int argc, char **argv)
           g_free (sd->screenshot_dir);
           sd->screenshot_dir = g_file_get_uri (default_save_dir);
 
-          // Check if given path is a directory
+          /* Check if given path is a directory */
           sd->path_is_dir = g_file_test (screenshot_dir, G_FILE_TEST_IS_DIR);
 
           g_object_unref (default_save_dir);
@@ -332,6 +330,8 @@ int main (int argc, char **argv)
   g_free (sd->screenshot_dir);
   g_free (sd->title);
   g_free (sd->app);
+  g_free (sd->custom_action_name);
+  g_free (sd->custom_action_command);
   g_free (sd->last_user);
   g_free (sd->last_extension);
   g_free (sd);
